@@ -160,7 +160,7 @@ schema <- tiledb_array_schema(dom,
 tiledb_array_create(tmp, schema)
 arr <- tiledb_array(tmp)
 qry <- tiledb_query(arr, "WRITE")
-qry <- tiledb_query_set_layout(qry, "ROW_MAJOR")
+if (tiledb_version(TRUE) < "2.12.0") qry <- tiledb_query_set_layout(qry, "ROW_MAJOR")
 
 rows <- 1:10
 qry <- tiledb_query_set_buffer(qry, "rows", rows)
@@ -198,6 +198,8 @@ expect_equal(tiledb_query_status(qry), "COMPLETE")
 
 keydat <- tiledb:::libtiledb_query_get_buffer_ptr(buf, FALSE)
 
+if (tiledb_version(TRUE) < "2.7.0") exit_file("Needs TileDB 2.7.* or later")
+
 n <- tiledb_query_result_buffer_elements(qry, "rows")
 expect_equal(n, 4L)
 expect_equal(rowdat[1:n], rows[4:7])
@@ -252,3 +254,21 @@ expect_true(is.character(res))
 expect_true(nchar(res) > 1000)  		# safe lower boundary
 
 ctx <- tiledb_ctx(oldcfg)               # reset config
+
+
+## check deletes
+if (tiledb_version(TRUE) < "2.12.0") exit_file("TileDB deletes requires TileDB 2.12.* or greater")
+if (!requireNamespace("palmerpenguins", quietly=TRUE)) exit_file("remainder needs 'palmerpenguins'")
+uri <- tempfile()
+pp <- palmerpenguins::penguins
+fromDataFrame(pp, uri, sparse = TRUE, col_index = c("species", "year"))
+
+qc <- parse_query_condition(body_mass_g > 4000 && sex == "male")
+arr <- tiledb_array(uri)
+qry <- tiledb_query(arr, "DELETE")
+qry <- tiledb_query_set_condition(qry, qc)
+tiledb_query_submit(qry)
+tiledb_query_finalize(qry)
+
+oo <- tiledb_array(uri, return_as="data.frame")[]
+expect_equal(nrow(oo), 177)             # instead of 344 pre-deletion
