@@ -138,6 +138,8 @@ tiledb_array_close(arr)
 rm(qry)
 
 
+if (tiledb_version(TRUE) < "2.7.0") exit_file("Needs TileDB 2.7.* or later")
+
 ## tiledb_array support
 if (!requireNamespace("palmerpenguins", quietly=TRUE)) exit_file("remainder needs 'palmerpenguins'")
 library(palmerpenguins)
@@ -185,6 +187,9 @@ expect_true(all(res$year == 2009))
 
 unlink(uri, recursive=TRUE)
 
+## (some) r-universe builds are/were breaking here
+if (Sys.getenv("MY_UNIVERSE", "") != "") exit_file("Skip remainder at r-universe")
+
 ## qc and string_ascii
 uri <- tempfile()
 fromDataFrame(na.omit(penguins), uri, sparse=TRUE)
