@@ -97,6 +97,7 @@ const tiledb_xptr_object tiledb_xptr_vfs_fh_t              		 { 160 };
 const tiledb_xptr_object tiledb_xptr_vlc_buf_t                   { 170 };
 const tiledb_xptr_object tiledb_xptr_vlv_buf_t                   { 180 };
 const tiledb_xptr_object tiledb_xptr_query_buf_t                 { 190 };
+const tiledb_xptr_object tiledb_xptr_object_subarray             { 200 };
 
 // templated checkers for external pointer tags
 template <typename T> const int32_t XPtrTagType                            = tiledb_xptr_default; // clang++ wants a value
@@ -119,6 +120,7 @@ template <> inline const int32_t XPtrTagType<vfs_fh_t>                     = til
 template <> inline const int32_t XPtrTagType<vlc_buf_t>                    = tiledb_xptr_vlc_buf_t;
 template <> inline const int32_t XPtrTagType<vlv_buf_t>                    = tiledb_xptr_vlv_buf_t;
 template <> inline const int32_t XPtrTagType<query_buf_t>                  = tiledb_xptr_query_buf_t;
+template <> inline const int32_t XPtrTagType<tiledb::Subarray>             = tiledb_xptr_object_subarray;
 
 template <typename T> XPtr<T> make_xptr(T* p) {
     return XPtr<T>(p, true, Rcpp::wrap(XPtrTagType<T>), R_NilValue);
